jupyterlab: An extensible environment for interactive and reproducible computing
================================================================================

Description
-----------

An extensible environment for interactive and reproducible computing,
based on the Jupyter Notebook and Architecture.

License
-------

BSD License

Upstream Contact
----------------

Home page: https://jupyter.org/

Dependencies
------------

- Python
- Setuptools
- jupyter_core
- jupyter_client
